// $Id: Menu.cpp,v 1.26 2009/09/09 02:29:47 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
   \file Menu.cc
   \brief   main menu
   \author Hugo Pereira
   \version $Revision: 1.26 $
   \date $Date: 2009/09/09 02:29:47 $
*/

#include "Application.h"
#include "DebugMenu.h"
#include "DefaultHelpText.h"
#include "HelpManager.h"
#include "Menu.h"
#include "Singleton.h"
#include "SvgHelpText.h"
#include "TransparencyHelpText.h"
#include "XmlOptions.h"

using namespace std;

//_______________________________________________
Menu::Menu( QWidget* parent ):
  QMenu( parent ),
  Counter( "Menu" )
{

  Debug::Throw( "Menu::Menu.\n" );

  // retrieve application
  Application& application( *Singleton::get().application<Application>() );

  // retrieve current Taskbar
  TaskBarBase& taskbar( *static_cast<TaskBarBase*>( parent ) );

  // task menu
  addAction( &taskbar.addButtonAction() );
  addAction( &taskbar.addSeparatorAction() );
  addAction( &taskbar.removeButtonAction() );
  addAction( &taskbar.editButtonAction() );
  addAction( &taskbar.editTaskListAction() );
  addSeparator();

  // taskbar menu
  addAction( &application.addTaskBarAction() );
  addAction( &application.removeTaskBarAction() );
  addAction( &taskbar.editAttributesAction() );

  addAction( &application.configurationAction() );
  QMenu *menu = addMenu( "&Flags" );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::LOCK_POSITION ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::AUTO_HIDE ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::STAYS_ON_TOP ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::STICKY ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::HIDE_FROM_TASKBAR ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::ROUND_CORNERS ) );
  menu->addSeparator();
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::LOCK_BUTTONS ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::SHOW_NAME ) );
  menu->addAction( &taskbar.flagAction( TaskBarAttributes::EXPAND_SEPARATORS ) );
  menu->addAction( &taskbar.toggleToolTipAction() );

  menu->addSeparator();

  menu->addAction( &taskbar.noHighlightAction() );
  menu->addAction( &taskbar.highlightOnEnterAction() );
  menu->addAction( &taskbar.highlightOnClickAction() );

  addSeparator();

  // help manager
  BASE::HelpManager* help( new BASE::HelpManager( this ) );
  File help_file( XmlOptions::get().raw( "HELP_FILE" ) );
  help->setWindowTitle( "Taskbar Handbook" );
  if( help_file.exists() ) help->install( help_file );
  else {
    help->setFile( help_file );
    help->install( TRANSPARENCY::HelpText, false );
    help->install( SVG::HelpText, false );
    help->install( BASE::HelpText, false );
  }

  // help menu
  menu = addMenu( "&Help" );
  menu->addAction( &help->displayAction() );
  menu->addSeparator();
  menu->addAction( &application.aboutAction() );
  menu->addAction( &application.aboutQtAction() );

  // debug menu
  #ifdef DEBUG
  menu->addSeparator();
  DebugMenu *debug_menu( new DebugMenu( this ) );
  debug_menu->setTitle( "&Debug" );
  addMenu( debug_menu );
  debug_menu->addAction( &taskbar.reloadBackgroundAction() );
  #endif

  // exit
  addSeparator();
  addAction( &application.closeAction() );
}
