#ifndef TaskParser_h
#define TaskParser_h

// $Id: TaskParser.h,v 1.6 2009/09/09 02:29:48 hpereira Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *
 *******************************************************************************/

/*!
  \file    TaskParser.h
  \brief   task parser based on xml
  \author  Hugo Pereira
  \version $Revision: 1.6 $
  \date    $Date: 2009/09/09 02:29:48 $
*/


#include <list>




#include "Counter.h"
#include "Debug.h"
#include "File.h"
#include "TaskBarAttributes.h"
#include "XmlError.h"

//! job parser based on Xml
class TaskParser: public Counter
{

  public:

  //! constructor
  TaskParser( void ):
    Counter( "TaskParser" )
  {}

  //! read from a file
  bool read( const File& file );

  //! write to file
  bool write( const File& file ) const;

  //! add attributes
  void addAttributes( const TaskBarAttributes& attributes )
  { attributes_list_.push_back( attributes ); }

  //! get attributes
  const TaskBarAttributes::List& attributes( void )
  {
    if( !attributes_list_.size() ) attributes_list_.push_back( TaskBarAttributes() );
    return attributes_list_;
  }

  //! Xml error
  const XmlError& xmlError( void ) const
  { return error_; }

  private:

  //! xml error message, if any
  XmlError error_;

  //! list of all read TaskBarAttributes
  TaskBarAttributes::List attributes_list_;

};

#endif
